@@ -1,9 +1,9 @@
 """Django email backend for celery."""
 
-VERSION = (1, 0, 3)
+VERSION = (1, 0, 4)
 
 __version__ = '.'.join(map(str, VERSION))
 __author__ = 'Paul McLanahan'
 __contact__ = 'paul@mclanahan.net'
-__homepage__ = 'http://bitbucket.org/pmclanahan/django-celery-email'
+__homepage__ = 'https://github.com/pmclanahan/django-celery-email'
 __license__ = 'BSD (3 clause)'
